Module content

Module content 

Content parts, display blocks, and tool return values.

Structs

AudioUrlPart
Audio URL content part wrapper.
DisplayBlock
A display block shown to the user in tool results or approval requests.
ImageUrlPart
Image URL content part wrapper.
MediaUrl
A media URL with an optional ID.
TextPart
Text content part.
ThinkPart
Thinking content part.
TodoDisplayItem
A single item in a todo display block.
ToolReturnValue
The result of a tool execution.
VideoUrlPart
Video URL content part wrapper.

Enums

ContentPart
A content part in a message.
DisplayBlockType
Discriminator for DisplayBlock types.
TodoStatus
Status of a todo display item.
ToolOutput
Tool output can be plain text or an array of content parts.
UserInput
User input can be plain text or an array of content parts.