#[non_exhaustive]pub enum Request {
ApprovalRequest(ApprovalRequest),
ToolCallRequest(ToolCallRequest),
QuestionRequest(QuestionRequest),
HookRequest(HookRequest),
}Expand description
A request from the agent to the client, sent via the request method.
The client must respond before the agent can continue execution.
Wire type names are PascalCase (e.g. ApprovalRequest).
Serialization follows the official wire envelope format:
{"type": "ApprovalRequest", "payload": {"id": ...}}.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ApprovalRequest(ApprovalRequest)
Request for user approval before executing a tool.
ToolCallRequest(ToolCallRequest)
Request to execute a tool.
QuestionRequest(QuestionRequest)
Interactive question for the user.
HookRequest(HookRequest)
Hook trigger notification.