Content parts, display blocks, and tool return values.
Structs
- Audio
UrlPart - Audio URL content part wrapper.
- Display
Block - A display block shown to the user in tool results or approval requests.
- Image
UrlPart - Image URL content part wrapper.
- Media
Url - A media URL with an optional ID.
- Text
Part - Text content part.
- Think
Part - Thinking content part.
- Todo
Display Item - A single item in a todo display block.
- Tool
Return Value - The result of a tool execution.
- Video
UrlPart - Video URL content part wrapper.
Enums
- Content
Part - A content part in a message.
- Display
Block Type - Discriminator for
DisplayBlocktypes. - Todo
Status - Status of a todo display item.
- Tool
Output - Tool output can be plain text or an array of content parts.
- User
Input - User input can be plain text or an array of content parts.